'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

const base00 = '#FAFAFA', // Lighter background
base01 = '#ECEFF1', // Light tooltip background
base02 = '#607D8B', // Less bright main text
base03 = '#90A4AE', // Secondary text
base04 = '#B0BEC5', // Cursor and line numbers
base05 = '#557C8D', // Variables and attributes
base06 = '#ECEFF1', // Light borders or divisions
base07 = '#FFFFFF', // Active line background
base_red = '#FF0000', // For errors and invalid
base_deeporange = '#FF7043', // Deep orange for tags
base_pink = '#FF4081', // Pink for definitions
base_yellow = '#ad8510', // Yellow for properties and headings
base_orange = '#FFA726', // Orange for types and classes
base_cyan = '#009EB3', // Cyan for links and keywords
base_indigo = '#5C6BC0', // Indigo for operators
base_purple = '#AB47BC', // Purple for labels and braces
base_green = '#1E951D', base_lightgreen = '#689E34'; // Teal for matching brackets
const invalid = base_red, highlightBackground = '#ECEFF1', // More visible highlight background
background = base00, tooltipBackground = base01, selection = '#DDEEFF', cursor = base04;
// Theme configuration adjusted for better contrast and color consistency
const materialLightTheme = view.EditorView.theme({
    '&': {
        color: base02,
        backgroundColor: background
    },
    '.cm-content': {
        caretColor: cursor
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor
    },
    // Adjusted panel colors for consistency
    '.cm-panels': {
        backgroundColor: base06,
        color: base03
    },
    // Updated search match styling for better visibility
    '.cm-searchMatch': {
        outline: `1px solid ${base_yellow}`,
        backgroundColor: 'rgba(255, 215, 64, 0.3)' // Semi-transparent
    },
    '.cm-activeLine': {
        backgroundColor: base07,
        color: base02
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection // Updated selection color
    },
    '.cm-gutters': {
        backgroundColor: background,
        borderRight: `1px solid ${base04}`,
        color: base03
    },
    '.cm-tooltip': {
        border: `1px solid ${base06}`,
        backgroundColor: tooltipBackground
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: highlightBackground,
            color: base03
        }
    }
}, { dark: false });
/// The highlighting style for code in the Material Dark theme.
const materialLightHighlightStyle = language.HighlightStyle.define([
    { tag: highlight.tags.keyword, color: base03 },
    {
        tag: [highlight.tags.name, highlight.tags.deleted, highlight.tags.character, highlight.tags.macroName],
        color: base_cyan
    },
    { tag: [highlight.tags.propertyName], color: base_yellow },
    { tag: [highlight.tags.variableName], color: base05 },
    { tag: [highlight.tags.function(highlight.tags.variableName)], color: base_cyan },
    { tag: [highlight.tags.labelName], color: base_purple },
    {
        tag: [highlight.tags.color, highlight.tags.constant(highlight.tags.name), highlight.tags.standard(highlight.tags.name)],
        color: base_yellow
    },
    { tag: [highlight.tags.definition(highlight.tags.name), highlight.tags.separator], color: base_pink },
    { tag: [highlight.tags.brace], color: base_purple },
    {
        tag: [highlight.tags.annotation],
        color: invalid
    },
    {
        tag: [highlight.tags.number, highlight.tags.changed, highlight.tags.annotation, highlight.tags.modifier, highlight.tags.self, highlight.tags.namespace],
        color: base_orange
    },
    {
        tag: [highlight.tags.typeName, highlight.tags.className],
        color: base_orange
    },
    {
        tag: [highlight.tags.operator, highlight.tags.operatorKeyword],
        color: base_indigo
    },
    {
        tag: [highlight.tags.tagName],
        color: base_deeporange
    },
    {
        tag: [highlight.tags.squareBracket],
        color: base_red
    },
    {
        tag: [highlight.tags.angleBracket],
        color: base02
    },
    {
        tag: [highlight.tags.attributeName],
        color: base05
    },
    {
        tag: [highlight.tags.regexp],
        color: invalid
    },
    {
        tag: [highlight.tags.quote],
        color: base_green
    },
    { tag: [highlight.tags.string], color: base_lightgreen },
    {
        tag: highlight.tags.link,
        color: base_cyan,
        textDecoration: 'underline',
        textUnderlinePosition: 'under'
    },
    {
        tag: [highlight.tags.url, highlight.tags.escape, highlight.tags.special(highlight.tags.string)],
        color: base_yellow
    },
    { tag: [highlight.tags.meta], color: base03 },
    { tag: [highlight.tags.comment], color: base03, fontStyle: 'italic' },
    { tag: highlight.tags.monospace, color: base05 },
    { tag: highlight.tags.strong, fontWeight: 'bold', color: base_red },
    { tag: highlight.tags.emphasis, fontStyle: 'italic', color: base_lightgreen },
    { tag: highlight.tags.strikethrough, textDecoration: 'line-through' },
    { tag: highlight.tags.heading, fontWeight: 'bold', color: base_yellow },
    { tag: highlight.tags.heading1, fontWeight: 'bold', color: base_yellow },
    {
        tag: [highlight.tags.heading2, highlight.tags.heading3, highlight.tags.heading4],
        fontWeight: 'bold',
        color: base_yellow
    },
    {
        tag: [highlight.tags.heading5, highlight.tags.heading6],
        color: base_yellow
    },
    { tag: [highlight.tags.atom, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)], color: base_cyan },
    {
        tag: [highlight.tags.processingInstruction, highlight.tags.inserted],
        color: base_red
    },
    {
        tag: [highlight.tags.contentSeparator],
        color: base_cyan
    },
    { tag: highlight.tags.invalid, color: base02, borderBottom: `1px dotted ${base_red}` }
]);
/// Extension to enable the Material Dark theme (both the editor theme and
/// the highlight style).
const materialLight = [
    materialLightTheme,
    language.syntaxHighlighting(materialLightHighlightStyle)
];

exports.materialLight = materialLight;
exports.materialLightHighlightStyle = materialLightHighlightStyle;
exports.materialLightTheme = materialLightTheme;
