import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

const base00 = '#FAFAFA', // Lighter background
base01 = '#ECEFF1', // Light tooltip background
base02 = '#607D8B', // Less bright main text
base03 = '#90A4AE', // Secondary text
base04 = '#B0BEC5', // Cursor and line numbers
base05 = '#557C8D', // Variables and attributes
base06 = '#ECEFF1', // Light borders or divisions
base07 = '#FFFFFF', // Active line background
base_red = '#FF0000', // For errors and invalid
base_deeporange = '#FF7043', // Deep orange for tags
base_pink = '#FF4081', // Pink for definitions
base_yellow = '#ad8510', // Yellow for properties and headings
base_orange = '#FFA726', // Orange for types and classes
base_cyan = '#009EB3', // Cyan for links and keywords
base_indigo = '#5C6BC0', // Indigo for operators
base_purple = '#AB47BC', // Purple for labels and braces
base_green = '#1E951D', base_lightgreen = '#689E34'; // Teal for matching brackets
const invalid = base_red, highlightBackground = '#ECEFF1', // More visible highlight background
background = base00, tooltipBackground = base01, selection = '#DDEEFF', cursor = base04;
// Theme configuration adjusted for better contrast and color consistency
const materialLightTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: base02,
        backgroundColor: background
    },
    '.cm-content': {
        caretColor: cursor
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor
    },
    // Adjusted panel colors for consistency
    '.cm-panels': {
        backgroundColor: base06,
        color: base03
    },
    // Updated search match styling for better visibility
    '.cm-searchMatch': {
        outline: `1px solid ${base_yellow}`,
        backgroundColor: 'rgba(255, 215, 64, 0.3)' // Semi-transparent
    },
    '.cm-activeLine': {
        backgroundColor: base07,
        color: base02
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection // Updated selection color
    },
    '.cm-gutters': {
        backgroundColor: background,
        borderRight: `1px solid ${base04}`,
        color: base03
    },
    '.cm-tooltip': {
        border: `1px solid ${base06}`,
        backgroundColor: tooltipBackground
    },
    '.cm-tooltip-autocomplete': {
        '& > ul > li[aria-selected]': {
            backgroundColor: highlightBackground,
            color: base03
        }
    }
}, { dark: false });
/// The highlighting style for code in the Material Dark theme.
const materialLightHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    { tag: tags.keyword, color: base03 },
    {
        tag: [tags.name, tags.deleted, tags.character, tags.macroName],
        color: base_cyan
    },
    { tag: [tags.propertyName], color: base_yellow },
    { tag: [tags.variableName], color: base05 },
    { tag: [/*@__PURE__*/tags.function(tags.variableName)], color: base_cyan },
    { tag: [tags.labelName], color: base_purple },
    {
        tag: [tags.color, /*@__PURE__*/tags.constant(tags.name), /*@__PURE__*/tags.standard(tags.name)],
        color: base_yellow
    },
    { tag: [/*@__PURE__*/tags.definition(tags.name), tags.separator], color: base_pink },
    { tag: [tags.brace], color: base_purple },
    {
        tag: [tags.annotation],
        color: invalid
    },
    {
        tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace],
        color: base_orange
    },
    {
        tag: [tags.typeName, tags.className],
        color: base_orange
    },
    {
        tag: [tags.operator, tags.operatorKeyword],
        color: base_indigo
    },
    {
        tag: [tags.tagName],
        color: base_deeporange
    },
    {
        tag: [tags.squareBracket],
        color: base_red
    },
    {
        tag: [tags.angleBracket],
        color: base02
    },
    {
        tag: [tags.attributeName],
        color: base05
    },
    {
        tag: [tags.regexp],
        color: invalid
    },
    {
        tag: [tags.quote],
        color: base_green
    },
    { tag: [tags.string], color: base_lightgreen },
    {
        tag: tags.link,
        color: base_cyan,
        textDecoration: 'underline',
        textUnderlinePosition: 'under'
    },
    {
        tag: [tags.url, tags.escape, /*@__PURE__*/tags.special(tags.string)],
        color: base_yellow
    },
    { tag: [tags.meta], color: base03 },
    { tag: [tags.comment], color: base03, fontStyle: 'italic' },
    { tag: tags.monospace, color: base05 },
    { tag: tags.strong, fontWeight: 'bold', color: base_red },
    { tag: tags.emphasis, fontStyle: 'italic', color: base_lightgreen },
    { tag: tags.strikethrough, textDecoration: 'line-through' },
    { tag: tags.heading, fontWeight: 'bold', color: base_yellow },
    { tag: tags.heading1, fontWeight: 'bold', color: base_yellow },
    {
        tag: [tags.heading2, tags.heading3, tags.heading4],
        fontWeight: 'bold',
        color: base_yellow
    },
    {
        tag: [tags.heading5, tags.heading6],
        color: base_yellow
    },
    { tag: [tags.atom, tags.bool, /*@__PURE__*/tags.special(tags.variableName)], color: base_cyan },
    {
        tag: [tags.processingInstruction, tags.inserted],
        color: base_red
    },
    {
        tag: [tags.contentSeparator],
        color: base_cyan
    },
    { tag: tags.invalid, color: base02, borderBottom: `1px dotted ${base_red}` }
]);
/// Extension to enable the Material Dark theme (both the editor theme and
/// the highlight style).
const materialLight = [
    materialLightTheme,
    /*@__PURE__*/syntaxHighlighting(materialLightHighlightStyle)
];

export { materialLight, materialLightHighlightStyle, materialLightTheme };
